#include <qlayout.h>

#include <kdebug.h>
#include <kglobal.h>
#include <kiconloader.h>
#include <klocale.h>
#include <kconfig.h>

#include <kmessagebox.h>

#include "kastasker.h"
#include "kasprefsdlg.h"
#include "kasaboutdlg.h"

#include "version.h"

#include "kasbarextension.h"
#include "kasbarextension.moc"

extern "C"
{
   KPanelExtension *init( QWidget *parent, const QString& configFile )
   {
      KGlobal::locale()->insertCatalogue("kasbarextension");
      return new KasBarExtension( configFile,
				  KPanelExtension::Normal,
				  KPanelExtension::About | KPanelExtension::Preferences,
				  parent, "kasbarextension");
   }
}

KasBarExtension::KasBarExtension( const QString& configFile,
                                  Type type,
                                  int actions,
                                  QWidget *parent, const char *name )
   : KPanelExtension( configFile, type, actions, parent, name )
{
    kdDebug(1345) << "KasBarExtension: Created '" << name << "', '" << configFile << "'" << endl;

//    setBackgroundMode( NoBackground );
    kasbar = new KasTasker( orientation(), this, name );
    connect( kasbar, SIGNAL( layoutChanged() ), this, SIGNAL( updateLayout() ) );
    kasbar->setConfig( config() );
    kasbar->readConfig();
    kasbar->refreshAll();
}

KasBarExtension::~KasBarExtension()
{
    KGlobal::locale()->removeCatalogue("kasbarextension");
}

void KasBarExtension::showEvent( QShowEvent */*se*/ )
{
    updateGeometry();
    resize( kasbar->size() );
    repaint( true );
}

QSize KasBarExtension::sizeHint(Position p, QSize maxSize ) const
{
   Orientation o = Horizontal;

   if ( p == Left || p == Right )
      o = Vertical;

   return kasbar->sizeHint( o, maxSize );
}

void KasBarExtension::positionChange( Position /* position */)
{
   kasbar->setOrientation( orientation() );
   kasbar->updateLayout();
   kasbar->refreshIconGeometry();
}

void KasBarExtension::about()
{
    kasbar->showAbout();
}

void KasBarExtension::preferences()
{
    kasbar->showPreferences();
}

